#!/usr/bin/perl

# Load testing for Template::Parser::LocalizeNewlines

use strict;
BEGIN {
	$|  = 1;
	$^W = 1;
}

use Test::More tests => 2;

ok( $] >= 5.005, 'Perl version is new enough' );

use_ok('Template::Parser::LocalizeNewlines');
